Learn R Programming

cocons (version 0.1.5)

getBoundariesV4: Simple build of boundaries

Description

provides a set of upper and lower bounds for the L-BFGS-B routine

Usage

getBoundariesV4(coco.object, lower.bound, upper.bound)

Value

(list) a list with boundaries and simple init values for the optim L-BFGS-B routine

Arguments

coco.object

(S4) a coco.object.

lower.bound

(numeric vector) lower bound for covariate-driven parameters of the nonstationary covariance function.

upper.bound

(numeric vector) upper bound for covariate-driven parameters of the nonstationary covariance function.

Author

Federico Blasi