Learn R Programming

cocons (version 0.1.5)

holes: Holes Data Set

Description

The synthetic "holes" provides a set of training and test data.frame of a Gaussian process realization with a (inherently dense) nonstationary covariance function. Four holes are present in the training dataset, and the task is to predict them.

Usage

holes

Arguments

Format

A list with training and test data.frame with rows and variables:

x

first spatial coordinate

y

second spatial coordinate

cox_x

first spatial characteristic

cov_y

second spatial characteristic

z

response variable

Examples

Run this code
data(holes)

Run the code above in your browser using DataLab