The synthetic "holes_bm" provides a set of training and test data.frame of a Gaussian process realization with a (inherently dense) nonstationary covariance function.
Four holes are present in the training dataset, and the task is to predict them. This version provides ten independent realizations of the process, as well as considers
a spatial mean effect.