provides a set of upper and lower bounds for the L-BFGS-B routine
getBoundariesV4(coco.object, lower.bound, upper.bound)(list) a list with boundaries and simple init values for the optim L-BFGS-B routine
(S4) a coco.object.
(numeric vector) lower bound for covariate-driven parameters of the nonstationary covariance function.
(numeric vector) upper bound for covariate-driven parameters of the nonstationary covariance function.
Federico Blasi