The synthetic "holes" provides a set of training and test data.frame of a Gaussian process realization with a (inherently dense) nonstationary covariance function.
Four holes are present in the training dataset, and the task is to predict them.
Usage
holes
Arguments
Format
A list with training and test data.frame with rows and variables: